==> nextguild-1.2.12.tar.gz: nextguild-1.2.12/README.md <==
# NextGuild
![image](https://user-images.githubusercontent.com/108808053/235311374-bdcdcdac-3c04-4b86-b336-1d2a02f5e914.png)




# About

NextGuild is a Guilded API wrapper written in Python.


Founded in 2023, the ©️ Nextguild Project (2023-present) is the most user-friendly Python library for interacting with the Guilded API. Because of our commitment to make it as simple and easy to use as possible, it serves as an excellent resource for both beginners learning Python programming and experienced programmers looking for a straightforward development experience. 

Made from a team of 2 people, this was a project originally thought for a fun purpose and for testing of the Guilded API, which eventually turned into a API wrapper for multi-purpose use.


Installation
------------
**[Python 3.7+](https://www.python.org/downloads/) is required**
```bash
# MacOS / Linux (via Terminal)
python3 -m pip install -U nextguild

# Windows (via CMD Prompt)
py -3 -m pip install -U nextguild
```

<br>NextGuild also requires 2 other packages to be installed before using it. <br>
If you haven't installed them already, execute the following command in your terminal:
```bash
pip install requests websockets
```

## Documentation

For NextGuild's official documentation, visit [this link](https://github.com/ArjunSharda/nextguild/tree/main/docs).

## Founders

[Arjun Sharda](https://github.com/ArjunSharda)<br>
[Erik Thorsell](https://github.com/erik-thorsell)

## Contributing

Please see the [CONTRIBUTING.MD](https://github.com/ArjunSharda/nextguild/blob/main/CONTRIBUTING.md) file for the official guidelines to contribute.

## License

©️ The NextGuild Project (2023-present) is under the [MIT](https://choosealicense.com/licenses/mit/) license, and usage of the library is subject to the terms of the MIT license.


<hr>
<h6 align="center">© The NextGuild Project 2023-present
<br>
All Rights Reserved</h6>

==> nextguild-1.2.14.tar.gz: nextguild-1.2.14/README.md <==
# NextGuild
![image](https://user-images.githubusercontent.com/108808053/235311374-bdcdcdac-3c04-4b86-b336-1d2a02f5e914.png)




# About

NextGuild is a Guilded API wrapper written in Python.


Founded in 2023, the ©️ Nextguild Project (2023-present) is the most user-friendly Python library for interacting with the Guilded API. Because of our commitment to make it as simple and easy to use as possible, it serves as an excellent resource for both beginners learning Python programming and experienced programmers looking for a straightforward development experience.


Made from a team of 2 people, this was a project originally thought for a fun purpose and for testing of the Guilded API, which eventually turned into a API wrapper for multi-purpose use.


Installation
------------
**[Python 3.7+](https://www.python.org/downloads/) is required**
```bash
# MacOS / Linux (via Terminal)
python3 -m pip install -U nextguild

# Windows (via CMD Prompt)
py -3 -m pip install -U nextguild
```

<br>NextGuild also requires 2 other packages to be installed before using it. <br>
> [!TIP]
> If you haven't installed them already, execute the following command in your terminal:
> ```bash
> pip install requests websockets
> ```

## Documentation

For NextGuild's official documentation, visit [this link](https://github.com/ArjunSharda/nextguild/tree/main/docs).

## Founders

[Arjun Sharda](https://github.com/ArjunSharda)<br>
[Erik Thorsell](https://github.com/erik-thorsell)

## Contributing

Please see the [CONTRIBUTING.MD](https://github.com/ArjunSharda/nextguild/blob/main/CONTRIBUTING.md) file for the official guidelines to contribute.

## License

©️ The NextGuild Project (2023-present) is under the [MIT](https://choosealicense.com/licenses/mit/) license, and usage of the library is subject to the terms of the MIT license.


<hr>
<h6 align="center">© The NextGuild Project 2023-present
<br>
All Rights Reserved</h6>
